@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.metastore_v1.services.dataproc_metastore import pagers
-from google.cloud.metastore_v1.types import metastore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
+
+from google.cloud.metastore_v1.services.dataproc_metastore import pagers
+from google.cloud.metastore_v1.types import metastore
+
 from .client import DataprocMetastoreClient
+from .transports.base import DEFAULT_CLIENT_INFO, DataprocMetastoreTransport
+from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
 
 
 class DataprocMetastoreAsyncClient:
@@ -250,11 +252,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_list_services():
+            async def sample_list_services():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.ListServicesRequest(
@@ -265,7 +274,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_services(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -328,12 +337,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServicesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -352,11 +369,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_get_service():
+            async def sample_get_service():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.GetServiceRequest(
@@ -364,7 +388,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_service(request=request)
+                response = await client.get_service(request=request)
 
                 # Handle the response
                 print(response)
@@ -426,7 +450,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -445,14 +474,20 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a metastore service in a project and
         location.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_create_service():
+            async def sample_create_service():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.CreateServiceRequest(
@@ -465,7 +500,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -558,7 +593,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -585,11 +625,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_update_service():
+            async def sample_update_service():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.UpdateServiceRequest(
@@ -600,7 +647,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -681,7 +728,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -707,11 +759,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_delete_service():
+            async def sample_delete_service():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.DeleteServiceRequest(
@@ -723,7 +782,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -762,9 +821,6 @@ class DataprocMetastoreAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -798,7 +854,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -824,11 +885,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_list_metadata_imports():
+            async def sample_list_metadata_imports():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.ListMetadataImportsRequest(
@@ -839,7 +907,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_metadata_imports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -902,12 +970,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListMetadataImportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -926,11 +1002,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_get_metadata_import():
+            async def sample_get_metadata_import():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.GetMetadataImportRequest(
@@ -938,7 +1021,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_metadata_import(request=request)
+                response = await client.get_metadata_import(request=request)
 
                 # Handle the response
                 print(response)
@@ -1000,7 +1083,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1019,14 +1107,20 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a new MetadataImport in a given project and
         location.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_create_metadata_import():
+            async def sample_create_metadata_import():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.CreateMetadataImportRequest(
@@ -1039,7 +1133,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1131,7 +1225,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1158,14 +1257,20 @@ class DataprocMetastoreAsyncClient:
         Only the description field of MetadataImport is
         supported to be updated.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_update_metadata_import():
+            async def sample_update_metadata_import():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.UpdateMetadataImportRequest(
@@ -1176,7 +1281,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1257,7 +1362,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1282,11 +1392,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_export_metadata():
+            async def sample_export_metadata():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.ExportMetadataRequest(
@@ -1299,7 +1416,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1341,7 +1458,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1368,11 +1490,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_restore_service():
+            async def sample_restore_service():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.RestoreServiceRequest(
@@ -1385,7 +1514,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1461,7 +1590,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1487,11 +1621,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_list_backups():
+            async def sample_list_backups():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.ListBackupsRequest(
@@ -1502,7 +1643,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_backups(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1565,12 +1706,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListBackupsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1589,11 +1738,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_get_backup():
+            async def sample_get_backup():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.GetBackupRequest(
@@ -1601,7 +1757,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_backup(request=request)
+                response = await client.get_backup(request=request)
 
                 # Handle the response
                 print(response)
@@ -1661,7 +1817,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1681,11 +1842,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_create_backup():
+            async def sample_create_backup():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.CreateBackupRequest(
@@ -1698,7 +1866,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1788,7 +1956,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1814,11 +1987,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1
 
-            def sample_delete_backup():
+            async def sample_delete_backup():
                 # Create a client
-                client = metastore_v1.DataprocMetastoreClient()
+                client = metastore_v1.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1.DeleteBackupRequest(
@@ -1830,7 +2010,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1869,9 +2049,6 @@ class DataprocMetastoreAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1905,7 +2082,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1927,7 +2109,9 @@ class DataprocMetastoreAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-metastore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-metastore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
