@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,14 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.metastore_v1alpha.services.dataproc_metastore import pagers
-from google.cloud.metastore_v1alpha.types import metastore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
+
+from google.cloud.metastore_v1alpha.services.dataproc_metastore import pagers
+from google.cloud.metastore_v1alpha.types import metastore
+
 from .client import DataprocMetastoreClient
+from .transports.base import DEFAULT_CLIENT_INFO, DataprocMetastoreTransport
+from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
 
 
 class DataprocMetastoreAsyncClient:
@@ -254,11 +256,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_list_services():
+            async def sample_list_services():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.ListServicesRequest(
@@ -269,7 +278,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_services(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -332,12 +341,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServicesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -356,11 +373,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_get_service():
+            async def sample_get_service():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.GetServiceRequest(
@@ -368,7 +392,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_service(request=request)
+                response = await client.get_service(request=request)
 
                 # Handle the response
                 print(response)
@@ -430,7 +454,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -449,14 +478,20 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a metastore service in a project and
         location.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_create_service():
+            async def sample_create_service():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.CreateServiceRequest(
@@ -469,7 +504,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -562,7 +597,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -589,11 +629,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_update_service():
+            async def sample_update_service():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.UpdateServiceRequest(
@@ -604,7 +651,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -685,7 +732,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -711,11 +763,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_delete_service():
+            async def sample_delete_service():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.DeleteServiceRequest(
@@ -727,7 +786,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -766,9 +825,6 @@ class DataprocMetastoreAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -802,7 +858,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -828,11 +889,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_list_metadata_imports():
+            async def sample_list_metadata_imports():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.ListMetadataImportsRequest(
@@ -843,7 +911,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_metadata_imports(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -906,12 +974,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListMetadataImportsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -930,11 +1006,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_get_metadata_import():
+            async def sample_get_metadata_import():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.GetMetadataImportRequest(
@@ -942,7 +1025,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_metadata_import(request=request)
+                response = await client.get_metadata_import(request=request)
 
                 # Handle the response
                 print(response)
@@ -1004,7 +1087,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1023,14 +1111,20 @@ class DataprocMetastoreAsyncClient:
         r"""Creates a new MetadataImport in a given project and
         location.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_create_metadata_import():
+            async def sample_create_metadata_import():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.CreateMetadataImportRequest(
@@ -1043,7 +1137,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1135,7 +1229,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1162,14 +1261,20 @@ class DataprocMetastoreAsyncClient:
         Only the description field of MetadataImport is
         supported to be updated.
 
-
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_update_metadata_import():
+            async def sample_update_metadata_import():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.UpdateMetadataImportRequest(
@@ -1180,7 +1285,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1261,7 +1366,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1286,11 +1396,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_export_metadata():
+            async def sample_export_metadata():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.ExportMetadataRequest(
@@ -1303,7 +1420,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1345,7 +1462,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1372,11 +1494,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_restore_service():
+            async def sample_restore_service():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.RestoreServiceRequest(
@@ -1389,7 +1518,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1465,7 +1594,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1491,11 +1625,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_list_backups():
+            async def sample_list_backups():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.ListBackupsRequest(
@@ -1506,7 +1647,7 @@ class DataprocMetastoreAsyncClient:
                 page_result = client.list_backups(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1569,12 +1710,20 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListBackupsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1593,11 +1742,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_get_backup():
+            async def sample_get_backup():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.GetBackupRequest(
@@ -1605,7 +1761,7 @@ class DataprocMetastoreAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_backup(request=request)
+                response = await client.get_backup(request=request)
 
                 # Handle the response
                 print(response)
@@ -1665,7 +1821,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1685,11 +1846,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_create_backup():
+            async def sample_create_backup():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.CreateBackupRequest(
@@ -1702,7 +1870,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1792,7 +1960,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1818,11 +1991,18 @@ class DataprocMetastoreAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1alpha
 
-            def sample_delete_backup():
+            async def sample_delete_backup():
                 # Create a client
-                client = metastore_v1alpha.DataprocMetastoreClient()
+                client = metastore_v1alpha.DataprocMetastoreAsyncClient()
 
                 # Initialize request argument(s)
                 request = metastore_v1alpha.DeleteBackupRequest(
@@ -1834,7 +2014,7 @@ class DataprocMetastoreAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1873,9 +2053,6 @@ class DataprocMetastoreAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1909,7 +2086,12 @@ class DataprocMetastoreAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1931,7 +2113,9 @@ class DataprocMetastoreAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-metastore",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-metastore",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
