@@ -521,6 +521,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_services(
@@ -536,6 +537,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_list_services():
@@ -646,6 +654,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_get_service():
@@ -746,6 +761,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_create_service():
@@ -888,6 +910,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_update_service():
@@ -1015,6 +1044,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_delete_service():
@@ -1070,9 +1106,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1137,6 +1170,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_list_metadata_imports():
@@ -1247,6 +1287,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_get_metadata_import():
@@ -1347,6 +1394,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_create_metadata_import():
@@ -1490,6 +1544,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_update_metadata_import():
@@ -1616,6 +1677,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_export_metadata():
@@ -1708,6 +1776,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_restore_service():
@@ -1832,6 +1907,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_list_backups():
@@ -1942,6 +2024,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_get_backup():
@@ -2039,6 +2128,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_create_backup():
@@ -2177,6 +2273,13 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import metastore_v1beta
 
             def sample_delete_backup():
@@ -2232,9 +2335,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
